@@ -2,6 +2,7 @@ mod utils;
 
 use crypto_market_type::MarketType;
 use crypto_msg_parser::{extract_symbol, parse_l2, parse_trade, TradeSide};
+use crypto_msg_type::MessageType;
 
 #[test]
 fn trade() {
@@ -56,6 +57,7 @@ fn l2_orderbook_snapshot() {
     crate::utils::check_orderbook_fields(
         "bithumb",
         MarketType::Spot,
+        MessageType::L2Event,
         "BTC/USDT".to_string(),
         extract_symbol("bithumb", MarketType::Spot, raw_msg).unwrap(),
         orderbook,
@@ -94,6 +96,7 @@ fn l2_orderbook_update() {
     crate::utils::check_orderbook_fields(
         "bithumb",
         MarketType::Spot,
+        MessageType::L2Event,
         "BTC/USDT".to_string(),
         extract_symbol("bithumb", MarketType::Spot, raw_msg).unwrap(),
         orderbook,
