@@ -228,6 +228,7 @@ mod funding_rate {
 mod l2_orderbook {
     use crypto_market_type::MarketType;
     use crypto_msg_parser::{extract_symbol, parse_l2};
+    use crypto_msg_type::MessageType;
 
     #[test]
     fn spot_snapshot() {
@@ -241,6 +242,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "okex",
             MarketType::Spot,
+            MessageType::L2Event,
             "BTC/USDT".to_string(),
             extract_symbol("okex", MarketType::Spot, raw_msg).unwrap(),
             orderbook,
@@ -270,6 +272,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "okex",
             MarketType::Spot,
+            MessageType::L2Event,
             "BTC/USDT".to_string(),
             extract_symbol("okex", MarketType::Spot, raw_msg).unwrap(),
             orderbook,
@@ -299,6 +302,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "okex",
             MarketType::LinearFuture,
+            MessageType::L2Event,
             "BTC/USDT".to_string(),
             extract_symbol("okex", MarketType::LinearFuture, raw_msg).unwrap(),
             orderbook,
@@ -330,6 +334,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "okex",
             MarketType::InverseSwap,
+            MessageType::L2Event,
             "BTC/USD".to_string(),
             extract_symbol("okex", MarketType::InverseSwap, raw_msg).unwrap(),
             orderbook,
@@ -361,6 +366,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "okex",
             MarketType::EuropeanOption,
+            MessageType::L2Event,
             "BTC/USD".to_string(),
             extract_symbol("okex", MarketType::EuropeanOption, raw_msg).unwrap(),
             orderbook,
